#!/usr/bin/env perl

# Pragmas.
use strict;
use warnings;

# Modules.
use Error::Pure::ErrorList qw(err);

# Error.
err '1';

# Output:
# #Error [example1.pl:9] 1